/*
 * RotDifference.java
 *
* Rotation differences in the CRANS algorithm are represented
 *  by this class (RotDifference).
 *
 *  "A Subgroup Algorithm to Identify Cross-Rotation Peaks
 *   Consistent with Non-Crystallographic Symmetry." R. H. Lilien,
 *   C. Bailey-Kellogg, A. C. Anderson, and B. R. Donald, Acta
 *   Crystallographica D, 60:1057-67 (2004).
 *
 * Ryan Lilien
 * Chris Bailey-Kellogg

////////////////////////////////////////////////////////////////////////////////////////////
//  RotDifference.java
//
//  Version:           0.1
//
//
// authors:
//    initials    name            organization                email
//   ---------   --------------  ------------------------    ------------------------------
//     RHL        Ryan Lilien     Dartmouth College           lilien@cs.dartmouth.edu
//
////////////////////////////////////////////////////////////////////////////////////////////

*/

package CRANS;

// A rotation difference

public class RotDifference {
    
    Rotation rot1 = null;
    Rotation rot2 = null;
    
    Quaternion diff = null;
    double[] axis = new double[3];
    double angle = 0.0;
    int nearestSymNumber = 0;
    double error = 0.0;         // The difference between this angle and 360/nSym
    boolean active = true;
    
    public RotDifference() {
        rot1 = null;
        rot2 = null;
        axis[0] = 0.0;
        axis[1] = 0.0;
        axis[2] = 0.0;
        angle = 0.0;
        nearestSymNumber = 0;
        error = 0.0;
        active = true;
    }
    
    public RotDifference(Rotation r1, Rotation r2, double[] axs, double ang,
                            int sNum, double err) {
        rot1 = r1;
        rot2 = r2;
        axis = axs;
        angle = ang;
        nearestSymNumber = sNum;
        error = err;
        active = true;
    }

}
