/*
 * Rotation.java
 *
 * Rotations in the CRANS algorithm are represented
 *  by this class (Rotation).
 *
 *  "A Subgroup Algorithm to Identify Cross-Rotation Peaks
 *   Consistent with Non-Crystallographic Symmetry." R. H. Lilien,
 *   C. Bailey-Kellogg, A. C. Anderson, and B. R. Donald, Acta
 *   Crystallographica D, 60:1057-67 (2004).
 *
 * Ryan Lilien
 * Chris Bailey-Kellogg

////////////////////////////////////////////////////////////////////////////////////////////
//  Rotation.java
//
//  Version:           0.1
//
//
// authors:
//    initials    name            organization                email
//   ---------   --------------  ------------------------    ------------------------------
//     RHL        Ryan Lilien     Dartmouth College           lilien@cs.dartmouth.edu
//
////////////////////////////////////////////////////////////////////////////////////////////

*/

package CRANS;

// Represents a rotation, if this is a dimer-symmetry-related
//  rotation then the dimerRotation boolean is set to true
//  and the associated original rotation is saved as well
// OrigString is the original rotation string, this is used
//  during output so that the user knows from where this
//  rotation came

public class Rotation {
    
    Quaternion rot;
    boolean dimerRotation = false;
    Quaternion origRot;
    float quality = 0.0f;
    String origString = null;
    int index = 0;
    boolean simulated = false;
    
    public Rotation() {
    }
    
    public Rotation(Quaternion q) {
        rot = q;
    }

    public Rotation(Quaternion q, Quaternion origQ) {
        rot = q;
        dimerRotation = true;
        origRot = origQ;
    }

    public Rotation(Quaternion q, String origS) {
        rot = q;
        origString = origS;
    }

    public Rotation(Quaternion q, Quaternion origQ, String origS) {
        rot = q;
        dimerRotation = true;
        origRot = origQ;
        origString = origS;
    }

}
